@@ -51,15 +51,15 @@ extract_to_callback (NautilusMenuItem *item,
 	uri = nautilus_file_info_get_uri (file);
 	path = gnome_vfs_get_local_path_from_uri (uri);
 	default_dir = g_strconcat ("file://", 
-				   g_get_home_dir(), 
+				   g_get_home_dir (), 
 				   "/",
 				   "Desktop", 
 				   NULL);
 	cmd = g_string_new ("file-roller");
 	g_string_append_printf (cmd, 
-				" --default-dir=\"%s\" --extract \"%s\"", 
-				default_dir,
-				path);
+				" --default-dir=%s --extract %s", 
+				g_shell_quote (default_dir),
+				g_shell_quote (path));
 
 #ifdef DEBUG
 	g_print ("EXEC: %s\n", cmd->str);
@@ -91,7 +91,7 @@ extract_here_callback (NautilusMenuItem *item,
 	dir = g_path_get_dirname (path);
 
 	cmd = g_string_new ("file-roller");
-	g_string_append_printf (cmd," --extract-to=\"%s\" --force", dir);
+	g_string_append_printf (cmd," --extract-to=%s --force", g_shell_quote (dir));
 
 	g_free (dir);
 	g_free (path);
@@ -103,7 +103,7 @@ extract_here_callback (NautilusMenuItem *item,
 		uri = nautilus_file_info_get_uri (file);
 		path = gnome_vfs_get_local_path_from_uri (uri);
 
-		g_string_append_printf (cmd, " \"%s\"", path);
+		g_string_append_printf (cmd, " %s", g_shell_quote (path));
 
 		g_free (path);
 		g_free (uri);
@@ -132,7 +132,7 @@ add_callback (NautilusMenuItem *item,
 	dir = g_path_get_dirname (path);
 
 	cmd = g_string_new ("file-roller");
-	g_string_append_printf (cmd," --default-dir=\"%s\" --add", dir);
+	g_string_append_printf (cmd," --default-dir=%s --add", g_shell_quote (dir));
 
 	g_free (dir);
 	g_free (path);
@@ -144,7 +144,7 @@ add_callback (NautilusMenuItem *item,
 		uri = nautilus_file_info_get_uri (file);
 		path = gnome_vfs_get_local_path_from_uri (uri);
 
-		g_string_append_printf (cmd, " \"%s\"", path);
+		g_string_append_printf (cmd, " %s", g_shell_quote (path));
 
 		g_free (path);
 		g_free (uri);
@@ -182,6 +182,7 @@ static char *mime_types[] = {
 	"application/x-zoo",
 	"application/x-cd-image",
 	"application/x-7z-compressed",
+	"application/x-gzpostscript",
 	NULL
 };
 
