@@ -25,7 +25,6 @@
 
 #include <gtk/gtk.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
-#include "egg-recent.h"
 #include "fr-archive.h"
 #include "typedefs.h"
 #include "file-list.h"
@@ -153,9 +152,16 @@ typedef struct {
 
 	GtkActionGroup  *actions;
 
+	/*
 	EggRecentViewGtk *recent_view_menu;
 	EggRecentViewGtk *recent_view_toolbar;
 	EggRecentModel   *recent_model;
+	*/
+
+	GtkRecentManager *recent_manager;
+	GtkWidget        *recent_chooser_menu;
+	GtkWidget        *recent_chooser_toolbar;
+
 	GtkWidget        *file_popup_menu;
 	GtkWidget        *mitem_recents_menu;
 	GtkWidget        *recent_toolbar_menu;
@@ -220,6 +226,7 @@ typedef struct {
 
 	gulong     theme_changed_handler_id;
 	gboolean   non_interactive;
+	char      *extract_here_dir;
 } FRWindow;
 
 
@@ -296,6 +303,15 @@ void       window_archive_extract           (FRWindow      *window,
 					     gboolean       junk_paths,
 					     const char    *password);
 
+void       window_archive_extract_here      (FRWindow      *window,
+					     GList         *file_list,
+					     const char    *extract_to_dir,
+					     const char    *base_dir,
+					     gboolean       skip_older,
+					     gboolean       overwrite,
+					     gboolean       junk_paths,
+					     const char    *password);
+
 void       window_archive_close             (FRWindow      *window);
 
 void       window_set_password              (FRWindow      *window,
